-- *******************************************************************
-- File: dbSchema.sql
-- Desc: data definition for phone-list app
-- Author:Brian Algeri
-- Create Date: 7/27/05
-- Rev: under darcs version control system
-- Database: sqlite 3.2.2
-- *******************************************************************

-- *****
-- BUILD
-- *****

-- sqlite3.exe PhoneList.db < dbSchema.sql

-- ===================================================================

BEGIN TRANSACTION;

-- *******
-- TABLES
-- *******

create table Persons (
  pid integer primary key,
  fname varchar,
  lname varchar,
  addr varchar,
  city varchar,
  sid integer,
  zip integer
);

-- ===================================================================

create table States (
  sid integer primary key,
  state
);

-- ===================================================================

create table PhoneTypes (
  ptid integer primary key,
  ptype varchar 
);

-- ===================================================================

create table PhoneList (
  plid integer primary key,
  pid integer,
  ptid integer,
  pnumber varchar,
  speedDial integer
);

-- ===================================================================

-- *******
-- VIEWS
-- *******

create view V1 as
  SELECT A.lname, A.fname, B.ptype,C.pnumber,C.speeddial
  FROM Persons A INNER JOIN PhoneList C
  ON A.pid = C.pid, PhoneTypes B
  WHERE C.ptid = B.ptid
  ORDER BY A.lname DESC, A.fname;

create view V2 as
  SELECT A.lname, A.fname, A.addr, A.city, B.state, A.zip
  FROM Persons A LEFT JOIN States B
  ON A.sid = B.sid
  ORDER BY A.lname, A.fname;

-- ===================================================================

-- ************
-- INITIAL DATA
-- ************

insert into States values (1,"Alaska");
insert into States values (2,"Ohio");
insert into States values (3,"New Jersey");
-- etc.

insert into PhoneTypes values (1,"Work");
insert into PhoneTypes values (2,"Home");
insert into PhoneTypes values (3,"Cell");

insert into Persons values (1,"Rick","Jones","1234 Street","Anytown",2,44444);
insert into Persons values (2,"Kate","Smith","5678 Street","Anytown",2,45444);
insert into Persons values (3,"Jeff","Doe","9123 Street","Anytown",3,48444);

insert into PhoneList values (1,1,2,1234567891,12);
insert into PhoneList values (2,1,1,3456789123,14);
insert into PhoneList values (3,2,2,5678912345,15);
insert into PhoneList values (4,3,3,8912345678,18);

COMMIT;

-- ===================================================================

-- *****
-- NOTES
-- *****

-- 'integer primary key' fields are autoincremented by null

-- *******************************************************************
